# Note: This expects FAMILY_NAME to have been set by calling script

PROCESSOR_FAMILY=$(cut /proc/navico_platform/cpuinfo -f2)

if [ -e /proc/navico_platform/mainboard_hw_rev ]; then
    HW_REVISION=$(cut /proc/navico_platform/mainboard_hw_rev -f1)
else
    HW_REVISION=0
fi

firmware_needed() {
    case ${FAMILY_NAME} in
        SonarHub)
            if [ "$(cut -f2 /proc/navico_platform/sonar_present)" = "true" ]; then
                return 0
            fi
            ;;
        Sylvester)
            # "Speedy Gonzalez" boards.
            if [ "$(cut -f2 /proc/navico_platform/sonar_present)" = "true" ]; then
                CHIRP_BIT=$(( ${HW_REVISION} & 2 ))
                if [ "${CHIRP_BIT}" = "2" ]; then
                    return 0
                fi
            fi
            ;;
        *)
            return 1
            ;;
    esac

    return 1
}

setup_gpio() {
    case ${FAMILY_NAME} in
        SonarHub)
            if [ "${PROCESSOR_FAMILY}" = "mx6" ]; then
                RESET_SONAR=132
                BOOT0_GPIO=141
            else
                RESET_SONAR=76
                BOOT0_GPIO=34
            fi
            ;;
        Sylvester)
            RESET_SONAR=56
            BOOT0_GPIO=55
            ;;
        *)
            return 1
            ;;
    esac

    RESET_SONAR_FILE="/sys/class/gpio/gpio${RESET_SONAR}/value"
    BOOT0_FILE="/sys/class/gpio/gpio${BOOT0_GPIO}/value"

    export_gpio ${RESET_SONAR} out
    export_gpio ${BOOT0_GPIO} out
}

setsonarresetline() {
    if [ ! -z "${RESET_SONAR}" ]; then
        echo $1 > /sys/class/gpio/gpio${RESET_SONAR}/value
    fi
}

enter_bootload() {
    setup_gpio
    echo 1 > ${BOOT0_FILE}
    setsonarresetline 0
    sleep 0.01
    setsonarresetline 1
    sleep 0.1
}

enter_runmode() {
    setup_gpio
    echo 0 > ${BOOT0_FILE}
    setsonarresetline 0
    sleep 0.01
    setsonarresetline 1
    sleep 0.1
}

serial_port() {
    case ${FAMILY_NAME} in
        SonarHub)
           echo /dev/ttyS1
           ;;
        Sylvester)                       
           echo /dev/ttyS4                          
           ;;                                       
        *)
           return 1                
           ;;                                      
    esac 
}
